summaryrefslogtreecommitdiff
path: root/apps/codecs/hes.c
diff options
context:
space:
mode:
authorAndree Buschmann <AndreeBuschmann@t-online.de>2011-08-30 19:40:09 +0000
committerAndree Buschmann <AndreeBuschmann@t-online.de>2011-08-30 19:40:09 +0000
commite88d24a8407ee3fca32cf08399ce895c49c80fc0 (patch)
treec1f5b054ae0a80ab4b72f33547742577d34c48ec /apps/codecs/hes.c
parente66ad3e8a86a19b9ef9480bc52766e61955f341d (diff)
downloadrockbox-e88d24a8407ee3fca32cf08399ce895c49c80fc0.zip
rockbox-e88d24a8407ee3fca32cf08399ce895c49c80fc0.tar.gz
rockbox-e88d24a8407ee3fca32cf08399ce895c49c80fc0.tar.bz2
rockbox-e88d24a8407ee3fca32cf08399ce895c49c80fc0.tar.xz
Submit parts of FS#12189 regarding codec API. Replaces access to global settings with a dedicated function to determine if the current track shall be looped. Used by several synthesizer codecs.
git-svn-id: svn://svn.rockbox.org/rockbox/trunk@30391 a1c6a512-1295-4272-9138-f99709370657
Diffstat (limited to 'apps/codecs/hes.c')
-rw-r--r--apps/codecs/hes.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/apps/codecs/hes.c b/apps/codecs/hes.c
index 8c216ed..c84134c 100644
--- a/apps/codecs/hes.c
+++ b/apps/codecs/hes.c
@@ -17,8 +17,8 @@ static struct Hes_Emu hes_emu;
static void set_codec_track(int t) {
Hes_start_track(&hes_emu, t);
- /* for REPEAT_ONE we disable track limits */
- if (ci->global_settings->repeat_mode != REPEAT_ONE) {
+ /* for loop mode we disable track limits */
+ if (!ci->loop_track()) {
Track_set_fade(&hes_emu, Track_get_length( &hes_emu, t ), 4000);
}
ci->set_elapsed(t*1000); /* t is track no to display */